* {
  box-sizing: border-box;
}

html,
body {
  margin: 0;
  padding: 0;
  width: 100%;
  height: 100%;
}

body {
  font-family: Verdana, Geneva, Tahoma, sans-serif;
  color: #333;
}

#main {
  padding: 1em;
}

.item {
  display: flex;
  flex-direction: row;
  align-items: flex-start;
  margin-top: 1em;
}

.col {
  margin: 0 1em;
}

.col:first-child {
  margin-left: 0;
}